import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class AlienLovesPredator(BasicComicModule):
    latestUrl = 'http://alienlovespredator.com/index.php'
    imageUrl = 'http://alienlovespredator.com/index.php?id=%s'
    imageSearch = re.compile(r'<img src="(http://planetavp\.com/alienlovespredator/strips/.+?)" width', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="(/index\.php\?id=\d+?)".+?nav_previous', re.IGNORECASE)
    help = 'Index format: nnn'
